@@ -19,13 +19,14 @@
 
 #include "nepomuksearchmodule.h"
 #include "searchurllistener.h"
-#include "nie.h"
 #include "dbusoperators_p.h"
 #include "timelinetools.h"
 
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusServiceWatcher>
 
+#include <Nepomuk/Vocabulary/NIE>
+
 #include <kdebug.h>
 #include <kdirnotify.h>
 
@@ -102,7 +103,7 @@ void Nepomuk::SearchModule::registerSearchUrl( const QString& urlString )
     else if ( isTimelineUrl( url ) ) {
         QDate date;
         if ( Nepomuk::parseTimelineUrl( url, &date ) == Nepomuk::DayFolder )
-            queryUrl = Nepomuk::buildTimelineQueryUrl( date );
+            queryUrl = Nepomuk::buildTimelineQuery( date ).toSearchUrl();
     }
 
     if ( queryUrl.isValid() ) {
