@@ -17,8 +17,6 @@
 */
 
 #include "metadatamover.h"
-#include "nie.h"
-#include "nfo.h"
 #include "nepomukfilewatch.h"
 
 #include <QtCore/QDir>
@@ -44,6 +42,9 @@
 #include <Nepomuk/Query/ResourceTerm>
 #include <Nepomuk/Query/LiteralTerm>
 
+#include <Nepomuk/Vocabulary/NFO>
+#include <Nepomuk/Vocabulary/NIE>
+
 #include <KDebug>
 
 
@@ -176,43 +177,46 @@ void Nepomuk::MetadataMover::removeMetadata( const KUrl& url )
         kDebug() << "empty path. Looks like a bug somewhere...";
     }
     else {
+        bool isFolder = url.url().endsWith('/');
         Resource res( url );
         if ( res.exists() ) {
             kDebug() << "removing metadata for file" << url << "with resource URI" << res.resourceUri();
             res.remove();
         }
 
-        //
-        // Recursively remove children
-        // We cannot use the nie:isPartOf relation since only children could have metadata. Thus, we do a regex
-        // match on all files and folders below the URL we got.
-        //
-        // CAUTION: The trailing slash on the from URL is essential! Otherwise we might match the newly added
-        //          URLs, too (in case a rename only added chars to the name)
-        //
-        const QString query = QString::fromLatin1( "select distinct ?r where { "
-                                                   "?r %1 ?url . "
-                                                   "FILTER(REGEX(STR(?url),'^%2')) . "
-                                                   "}" )
-                              .arg( Soprano::Node::resourceToN3( Nepomuk::Vocabulary::NIE::url() ),
-                                    url.url(KUrl::AddTrailingSlash) );
-        kDebug() << query;
+        if( isFolder ) {
+            //
+            // Recursively remove children
+            // We cannot use the nie:isPartOf relation since only children could have metadata. Thus, we do a regex
+            // match on all files and folders below the URL we got.
+            //
+            // CAUTION: The trailing slash on the from URL is essential! Otherwise we might match the newly added
+            //          URLs, too (in case a rename only added chars to the name)
+            //
+            const QString query = QString::fromLatin1( "select distinct ?r where { "
+                                                    "?r %1 ?url . "
+                                                    "FILTER(REGEX(STR(?url),'^%2')) . "
+                                                    "}" )
+                                .arg( Soprano::Node::resourceToN3( Nepomuk::Vocabulary::NIE::url() ),
+                                        url.url(KUrl::AddTrailingSlash) );
+            kDebug() << query;
 
-        //
-        // We cannot use one big loop since our updateMetadata calls below can change the iterator
-        // which could have bad effects like row skipping. Thus, we handle the urls in chunks of
-        // cached items.
-        //
-        while ( 1 ) {
-            QList<Soprano::Node> urls = m_model->executeQuery( query + QLatin1String( " LIMIT 100" ),
-                                                               Soprano::Query::QueryLanguageSparql )
-                                        .iterateBindings( 0 ).allNodes();
-            if ( urls.isEmpty() )
-                break;
+            //
+            // We cannot use one big loop since our updateMetadata calls below can change the iterator
+            // which could have bad effects like row skipping. Thus, we handle the urls in chunks of
+            // cached items.
+            //
+            while ( 1 ) {
+                QList<Soprano::Node> urls = m_model->executeQuery( query + QLatin1String( " LIMIT 100" ),
+                                                                Soprano::Query::QueryLanguageSparql )
+                                            .iterateBindings( 0 ).allNodes();
+                if ( urls.isEmpty() )
+                    break;
 
-            for ( int i = 0; i < urls.count(); ++i ) {
-                // the old URL of the resource to update
-                Resource::fromResourceUri( urls[i].uri() ).remove();
+                for ( int i = 0; i < urls.count(); ++i ) {
+                    // the old URL of the resource to update
+                    Resource::fromResourceUri( urls[i].uri() ).remove();
+                }
             }
         }
     }
