@@ -50,6 +50,16 @@ namespace Nepomuk {
 
         void stop();
 
+    Q_SIGNALS:
+        /**
+         * Emitted for files (and folders) that have been moved but
+         * do not have metadata to be moved. This allows the strigi
+         * service to pick them up in case they are of interest. The
+         * typical example would be moving a file from a non-indexed into
+         * an indexed folder.
+         */
+        void movedWithoutData( const QString& path );
+
     private Q_SLOTS:
         void slotClearRecentlyFinishedRequests();
 
@@ -68,7 +78,7 @@ namespace Nepomuk {
          * If old pre-KDE 4.4 file:/ resource URIs are used these are
          * updated to the new nepomuk:/res/<UUID> scheme
          */
-        void updateMetadata( const KUrl& from, const KUrl& to );
+        void updateMetadata( const KUrl& from, const KUrl& to, bool includeChildren = true );
 
         /**
          * Convert old pre-KDE 4.4 style file:/ resource URIs to the
