@@ -91,12 +91,14 @@ namespace {
     {
         Q_UNUSED( flags );
 
-        //Only watch the strigi index folders for file creation.
+        //Only watch the strigi index folders for file creation and change.
         if( Nepomuk::StrigiServiceConfig::self()->shouldFolderBeIndexed( path ) ) {
             modes |= KInotify::EventCreate;
+            modes |= KInotify::EventModify;
         }
         else {
             modes &= (~KInotify::EventCreate);
+            modes &= (~KInotify::EventModify);
         }
 
         return true;
@@ -174,7 +176,7 @@ void Nepomuk::FileWatch::watchFolder( const QString& path )
 #ifdef BUILD_KINOTIFY
     if ( m_dirWatch && !m_dirWatch->watchingPath( path ) )
         m_dirWatch->addWatch( path,
-                              KInotify::WatchEvents( KInotify::EventMove|KInotify::EventDelete|KInotify::EventDeleteSelf|KInotify::EventCreate ),
+                              KInotify::WatchEvents( KInotify::EventMove|KInotify::EventDelete|KInotify::EventDeleteSelf|KInotify::EventCreate|KInotify::EventModify ),
                               KInotify::WatchFlags() );
 #endif
 }
@@ -249,7 +251,7 @@ void Nepomuk::FileWatch::updateFolderViaStrigi( const QString& path )
         //
         org::kde::nepomuk::Strigi strigi( "org.kde.nepomuk.services.nepomukstrigiservice", "/nepomukstrigiservice", QDBusConnection::sessionBus() );
         if ( strigi.isValid() ) {
-            strigi.updateFolder( path, false /* no forced update */ );
+            strigi.updateFolder( path, false /* non-recursive */, false /* no forced update */ );
         }
     }
 }
@@ -297,5 +299,4 @@ void Nepomuk::FileWatch::updateIndexedFoldersWatches()
 #endif
 }
 
-
 #include "nepomukfilewatch.moc"
