@@ -217,7 +217,7 @@ QString Nepomuk::StrigiService::currentFolder() const
 }
 
 
-void Nepomuk::StrigiService::updateFolder(const QString& path, bool forced)
+void Nepomuk::StrigiService::updateFolder(const QString& path, bool recursive, bool forced)
 {
     kDebug() << "Called with path: " << path;
     QFileInfo info( path );
@@ -229,8 +229,7 @@ void Nepomuk::StrigiService::updateFolder(const QString& path, bool forced)
             dirPath = info.absolutePath();
 
         if ( StrigiServiceConfig::self()->shouldFolderBeIndexed( dirPath ) ) {
-            kDebug() << "Updating : " << dirPath;
-            m_indexScheduler->updateDir( dirPath, forced );
+            indexFolder(path, recursive, forced);
         }
     }
 }
@@ -247,9 +246,8 @@ void Nepomuk::StrigiService::indexFile(const QString& path)
     m_indexScheduler->analyzeFile( path );
 }
 
-//FIXME: Code duplication in updateFolder, avoid if possible. Maybe with an extra
-//       default parameter
-void Nepomuk::StrigiService::indexFolder(const QString& path, bool forced)
+
+void Nepomuk::StrigiService::indexFolder(const QString& path, bool recursive, bool forced)
 {
     QFileInfo info( path );
     if ( info.exists() ) {
@@ -259,7 +257,15 @@ void Nepomuk::StrigiService::indexFolder(const QString& path, bool forced)
         else
             dirPath = info.absolutePath();
 
-        m_indexScheduler->updateDir( dirPath, forced );
+        kDebug() << "Updating : " << dirPath;
+
+        Nepomuk::IndexScheduler::UpdateDirFlags flags;
+        if(recursive)
+            flags |= Nepomuk::IndexScheduler::UpdateRecursive;
+        if(forced)
+            flags |= Nepomuk::IndexScheduler::ForceUpdate;
+
+        m_indexScheduler->updateDir( dirPath, flags );
     }
 }
 
