@@ -18,14 +18,14 @@
 
 #include "strigiserviceconfig.h"
 #include "removablestorageserviceinterface.h"
-#include "strigiservicedefaults.h"
+#include "fileexcludefilters.h"
 
 #include <QtCore/QStringList>
 #include <QtCore/QDir>
 
-#include <kdirwatch.h>
-#include <kstandarddirs.h>
-#include <kconfiggroup.h>
+#include <KDirWatch>
+#include <KStandardDirs>
+#include <KConfigGroup>
 
 
 Nepomuk::StrigiServiceConfig::StrigiServiceConfig()
@@ -91,7 +91,7 @@ QStringList Nepomuk::StrigiServiceConfig::excludeFilters() const
 }
 
 
-bool Nepomuk::StrigiServiceConfig::indexHiddenFolders() const
+bool Nepomuk::StrigiServiceConfig::indexHiddenFilesAndFolders() const
 {
     return m_config.group( "General" ).readEntry( "index hidden folders", false );
 }
@@ -119,6 +119,20 @@ bool Nepomuk::StrigiServiceConfig::isInitialRun() const
 }
 
 
+bool Nepomuk::StrigiServiceConfig::shouldBeIndexed( const QString& path ) const
+{
+    QFileInfo fi( path );
+    if( fi.isDir() ) {
+        return shouldFolderBeIndexed( path );
+    }
+    else {
+        return( shouldFolderBeIndexed( fi.absolutePath() ) &&
+                ( !fi.isHidden() || indexHiddenFilesAndFolders() ) &&
+                shouldFileBeIndexed( fi.fileName() ) );
+    }
+}
+
+
 namespace {
     /// recursively check if a folder is hidden
     bool isDirHidden( QDir& dir ) {
@@ -142,10 +156,10 @@ bool Nepomuk::StrigiServiceConfig::shouldFolderBeIndexed( const QString& path )
 
         // check for hidden folders
         QDir dir( path );
-        if ( !indexHiddenFolders() && isDirHidden( dir ) )
+        if ( !indexHiddenFilesAndFolders() && isDirHidden( dir ) )
             return false;
 
-        // reset dir
+        // reset dir, cause isDirHidden modifies the QDir
         dir = path;
 
         // check the filters
@@ -160,12 +174,7 @@ bool Nepomuk::StrigiServiceConfig::shouldFolderBeIndexed( const QString& path )
 bool Nepomuk::StrigiServiceConfig::shouldFileBeIndexed( const QString& fileName ) const
 {
     // check the filters
-    foreach( const QRegExp& filter, m_excludeFilterRegExpCache ) {
-        if ( filter.exactMatch( fileName ) ) {
-            return false;
-        }
-    }
-    return true;
+    return !m_excludeFilterRegExpCache.exactMatch( fileName );
 }
 
 
@@ -257,13 +266,7 @@ void Nepomuk::StrigiServiceConfig::buildFolderCache()
 
 void Nepomuk::StrigiServiceConfig::buildExcludeFilterRegExpCache()
 {
-    m_excludeFilterRegExpCache.clear();
-    foreach( const QString& filter, excludeFilters() ) {
-        QString filterRxStr = QRegExp::escape( filter );
-        filterRxStr.replace( "\\*", QLatin1String( ".*" ) );
-        filterRxStr.replace( "\\?", QLatin1String( "." ) );
-        m_excludeFilterRegExpCache << QRegExp( filterRxStr );
-    }
+    m_excludeFilterRegExpCache.rebuildCacheFromFilterList( excludeFilters() );
 }
 
 #include "strigiserviceconfig.moc"
