@@ -44,7 +44,6 @@
 #include <Solid/GenericInterface>
 #include <Solid/Device>
 #include <Solid/DeviceNotifier>
-#include <phonon/phononnamespace.h>
 
 #include <../config-alsa.h>
 #ifdef HAVE_LIBASOUND2
@@ -56,11 +55,6 @@ K_PLUGIN_FACTORY(PhononServerFactory,
         )
 K_EXPORT_PLUGIN(PhononServerFactory("phononserver"))
 
-typedef QList<QPair<QByteArray, QString> > PhononDeviceAccessList;
-#if (PHONON_VERSION < PHONON_VERSION_CHECK(4, 4, 3))
-Q_DECLARE_METATYPE(PhononDeviceAccessList)
-#endif
-
 PhononServer::PhononServer(QObject *parent, const QList<QVariant> &)
     : KDEDModule(parent),
     m_config(KSharedConfig::openConfig("phonondevicesrc", KConfig::SimpleConfig))
@@ -68,8 +62,8 @@ PhononServer::PhononServer(QObject *parent, const QList<QVariant> &)
     findDevices();
     connect(Solid::DeviceNotifier::instance(), SIGNAL(deviceAdded(const QString &)), SLOT(deviceAdded(const QString &)));
     connect(Solid::DeviceNotifier::instance(), SIGNAL(deviceRemoved(const QString &)), SLOT(deviceRemoved(const QString &)));
-    qRegisterMetaType<PhononDeviceAccessList>();
-    qRegisterMetaTypeStreamOperators<PhononDeviceAccessList>("PhononDeviceAccessList");
+
+    Phonon::registerMetaTypes();
 }
 
 PhononServer::~PhononServer()
@@ -78,6 +72,9 @@ PhononServer::~PhononServer()
 
 static QString uniqueId(const Solid::Device &device, int deviceNumber)
 {
+    Q_UNUSED(deviceNumber);
+    return device.udi();
+#if 0
     const Solid::GenericInterface *genericIface = device.as<Solid::GenericInterface>();
     Q_ASSERT(genericIface);
     const QString &subsystem = genericIface->propertyExists(QLatin1String("info.subsystem")) ?
@@ -121,6 +118,7 @@ static QString uniqueId(const Solid::Device &device, int deviceNumber)
         }
     }
     return QString();
+#endif
 }
 
 static void renameDevices(QList<PS::AudioDevice> *devicelist)
@@ -694,7 +692,7 @@ void PhononServer::updateAudioDevicesCache()
         properties.insert("initialPreference", dev.initialPreference());
         properties.insert("isAdvanced", dev.isAdvanced());
         properties.insert("icon", dev.icon());
-        PhononDeviceAccessList deviceAccessList;
+        Phonon::DeviceAccessList deviceAccessList;
         bool first = true;
         QStringList oldDeviceIds;
         PS::AudioDeviceAccess::AudioDriver driverId = PS::AudioDeviceAccess::InvalidDriver;
@@ -710,7 +708,7 @@ void PhononServer::updateAudioDevicesCache()
                 if (access.driver() == driverId) {
                     oldDeviceIds << deviceId;
                 }
-                deviceAccessList << QPair<QByteArray, QString>(driver, deviceId);
+                deviceAccessList << Phonon::DeviceAccess(driver, deviceId);
             }
         }
         properties.insert("deviceAccessList", QVariant::fromValue(deviceAccessList));
@@ -732,11 +730,11 @@ void PhononServer::updateAudioDevicesCache()
         properties.insert("initialPreference", dev.initialPreference());
         properties.insert("isAdvanced", dev.isAdvanced());
         properties.insert("icon", dev.icon());
-        PhononDeviceAccessList deviceAccessList;
+        Phonon::DeviceAccessList deviceAccessList;
         foreach (const PS::AudioDeviceAccess &access, dev.accessList()) {
             const QByteArray &driver = nameForDriver(access.driver());
             foreach (const QString &deviceId, access.deviceIds()) {
-                deviceAccessList << QPair<QByteArray, QString>(driver, deviceId);
+                deviceAccessList << Phonon::DeviceAccess(driver, deviceId);
             }
         }
         properties.insert("deviceAccessList", QVariant::fromValue(deviceAccessList));
